Developer Documentation — django-geopostcodes 0.1.0 documentation

# Developer Documentation

## Contributions

Contributions are more than welcomed!

To get setup do the following;

    mkvirtualenv --python=/usr/bin/python3 django-geopostcodes
    git clone https://github.com/alexhayes/django-geopostcodes.git
    cd django-geopostcodes
    pip install -r requirements/dev.txt

Note that you don’t have to use Python 3 and indeed tox tests for many versions of Python, but you may as well develop on it, what reason is there not to for such a small application?!

## Running Tests

Once you’ve checked out you should be able to run the tests.

    detox

or, alternatively;

    ./manage.py test

## Migrations

If you need to make modelling changes please run `makemigrations` so that the migration is included in your pull request.

    ./manage.py makemigrations

## Creating translations

Translations are welcomed! Please fork and then from the root

    cd django_geopostcodes
    ./../manage.py makemessages -l [LOCALE-NAME]

Then, edit the translations in `django_geopostcodes/locale`, then;

    ./../manage.py compilemessages

## Creating Documentation

    cd docs
    make clean html